@@ -37,7 +37,11 @@
 #include "libgcpcanvas/gcp-canvas-group.h"
 #include "libgcpcanvas/gcp-canvas-rect-ellipse.h"
 #include "libgcpcanvas/gcp-canvas-line.h"
-#include <chemistry/element.h>
+#ifdef GCU_OLD_VER
+#	include <chemistry/element.h>
+#else
+#	include <gcu/element.h>
+#endif
 #include <math.h>
 
 extern GtkTextTagTable *TextTagTable;
@@ -100,6 +104,15 @@ bool gcpFragment::OnChanged(GtkTextBuffer *textbuffer)
 	}
 	GdkRectangle rect;
 	GtkTextIter start, iter;
+	if (!gtk_text_buffer_get_char_count (m_buf)) {
+		gtk_text_buffer_get_start_iter(m_buf,&iter);
+		gnome_canvas_rich_text_ext_get_iter_location(text, &iter, &rect);
+		m_height = rect.height + 1;
+		m_length = 1;
+		pView->Update (this);
+		m_bLoading = false;
+		return true;
+	}
 	gtk_text_buffer_get_end_iter(m_buf,&iter);
 	gnome_canvas_rich_text_ext_get_iter_location(text, &iter, &rect);
 	m_length = rect.x + 1;
@@ -612,7 +625,11 @@ bool gcpFragment::Load(xmlNodePtr node)
 		if (!strcmp((const char*)child->name, "text"))
 		{
 			tmp = (char*) xmlNodeGetContent(child);
-			gtk_text_buffer_insert(m_buf, &iter, tmp, -1);
+			if (tmp)
+			{
+				gtk_text_buffer_insert(m_buf, &iter, tmp, -1);
+				xmlFree(tmp);
+			}
 		}
 		else if (!strcmp((const char*)child->name, "atom"))
 		{
@@ -630,7 +647,13 @@ bool gcpFragment::Load(xmlNodePtr node)
 		else if (!strcmp((const char*)child->name, "charge"))
 		{
 			tmp = (char*) xmlGetProp(child, (xmlChar*)"value");
-			int charge = atoi(tmp);
+			int charge;
+			if (tmp)
+			{
+				charge = atoi(tmp);
+				xmlFree(tmp);
+			}
+			else charge = 0;
 			if (abs(charge) > 1)
 				tmp = g_strdup_printf("%d%c",charge, (charge > 0)? '+': '-');
 			else if (charge == 1)
