@@ -35,7 +35,11 @@
 #include <libgnomeprintui/gnome-print-dialog.h>
 #include <libgnomeprintui/gnome-print-job-preview.h>
 #include <glib-object.h>
-#include <chemistry/chemistry.h>
+#ifdef GCU_OLD_VER
+#	include <chemistry/chemistry.h>
+#else
+#	include <gcu/chemistry.h>
+#endif
 #include "document.h"
 #include "tools.h"
 #include "mendeleiev.h"
@@ -330,6 +334,20 @@ static bool do_save_as_image(GtkWidget* widget, GtkFileSelection *fsel)
 		gtk_widget_destroy (message);
 		return true;
 	}
+	struct stat buf;
+	gint err;
+	gint result = GTK_RESPONSE_YES;
+	err = stat(filename, &buf);
+	if (!err)
+	{
+		gchar * message = g_strdup_printf(_("File %s\nexists, overwrite?"), filename);
+		GtkDialog* Box = GTK_DIALOG(gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
+		result = gtk_dialog_run(Box);
+		gtk_widget_destroy(GTK_WIDGET(Box));
+		g_free(message);
+		if (result != GTK_RESPONSE_YES)
+			return true;
+	}
 	const char* mime_type = gnome_vfs_mime_type_from_name (filename);
 	if (SupportedPixbufFormats.find (mime_type) != SupportedPixbufFormats.end()) {
 		pActiveDoc->GetView ()->ExportImage (filename, SupportedPixbufFormats[mime_type].c_str ());
@@ -339,8 +357,6 @@ static bool do_save_as_image(GtkWidget* widget, GtkFileSelection *fsel)
 	else if (!strcmp (mime_type, "image/x-eps")) {
 		char *result = NULL;
 		g_spawn_command_line_sync ("which ps2eps", &result, NULL, NULL, NULL);
-printf("result:%x\n",result);
-if (result) printf("result length:%x\n",strlen(result));
 		if (result && strlen (result)) {
 			pActiveDoc->GetView ()->ExportImage (filename, "eps");
 			gtk_widget_destroy (GTK_WIDGET (fsel));
